@@ -2,7 +2,7 @@
 
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2008 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -474,7 +474,7 @@ struct _FolderClass
 	gint     	(*add_msgs)             (Folder         *folder,
                                     		 FolderItem     *dest,
                                     		 GSList         *file_list,
-                                    		 GRelation	*relation);
+                                    		 GHashTable	*relation);
 	/**
 	 * Copy a message to a FolderItem
 	 *
@@ -505,7 +505,7 @@ struct _FolderClass
 	gint    	(*copy_msgs)		(Folder		*folder,
 						 FolderItem	*dest,
 						 MsgInfoList	*msglist,
-                                    		 GRelation	*relation);
+                                    		 GHashTable	*relation);
 	/**
 	 * Remove a message from a \c FolderItem.
 	 *
@@ -520,7 +520,9 @@ struct _FolderClass
 	gint    	(*remove_msgs)		(Folder		*folder,
 						 FolderItem	*item,
 						 MsgInfoList    *msglist,
-						 GRelation	*relation);
+						 GHashTable	*relation);
+	gint    	(*expunge)		(Folder		*folder,
+						 FolderItem	*item);
 	/**
 	 * Remove all messages in a \ c FolderItem
 	 *
@@ -576,7 +578,7 @@ struct _FolderClass
 	gint		(*get_flags)		(Folder		*folder,
 						 FolderItem	*item,
 						 MsgInfoList	*msglist,
-						 GRelation	*msgflags);
+						 GHashTable	*msgflags);
 	
 	/* Sets batch mode for a FolderItem. It means that numerous flags updates
 	 * could follow, and the FolderClass implementation can cache them in order
@@ -656,6 +658,9 @@ struct _FolderItem
 	gint last_num;
 
 	MsgCache *cache;
+	gboolean cache_dirty;
+	gboolean mark_dirty;
+	gboolean tags_dirty;
 
 	/* special flags */
 	guint no_sub         : 1; /* no child allowed?    */
@@ -666,6 +671,7 @@ struct _FolderItem
 	guint hide_read_msgs : 1; /* hide read messages   */
 	guint ret_rcpt       : 1; /* return receipt       */
 	guint search_match   : 1;
+	guint hide_del_msgs : 1; /* hide deleted messages   */
 
 	gint op_count;
 	guint opened         : 1; /* opened by summary view */
@@ -704,6 +710,7 @@ struct _PersistPrefs
 	guint		threaded	: 1;
 	guint		hide_read_msgs	: 1; /* CLAWS */
 	guint		ret_rcpt	: 1; /* CLAWS */
+	guint		hide_del_msgs	: 1; /* CLAWS */
 };
 
 struct _FolderUpdateData
@@ -781,6 +788,7 @@ void folder_count_total_msgs(guint *new_msgs, guint *unread_msgs,
 gchar *folder_get_status	(GPtrArray	*folders,
 				 gboolean	 full);
 
+Folder 	   *folder_find_from_identifier		(const gchar *identifier);
 Folder     *folder_find_from_path		(const gchar	*path);
 Folder     *folder_find_from_name		(const gchar	*name,
 						 FolderClass	*klass);
@@ -794,6 +802,7 @@ gchar 	   *folder_get_identifier		(Folder *folder);
 /* return value is locale charset */
 gchar      *folder_item_get_identifier		(FolderItem	*item);
 FolderItem *folder_find_item_from_identifier	(const gchar	*identifier);
+FolderItem *folder_get_item_from_identifier	(const gchar	*identifier);
 gchar 	   *folder_item_get_name		(FolderItem 	*item);
 
 FolderItem *folder_get_default_inbox	(void);
@@ -853,6 +862,7 @@ gint   folder_item_remove_msg		(FolderItem	*item,
 					 gint		 num);
 gint   folder_item_remove_msgs		(FolderItem	*item,
 					 GSList		*msglist);
+gint   folder_item_expunge		(FolderItem	*item);
 gint   folder_item_remove_all_msg	(FolderItem	*item);
 void 	folder_item_change_msg_flags	(FolderItem 	*item,
 					 MsgInfo 	*msginfo,
