@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,6 +44,12 @@ struct _FolderItemPrefs {
 	gchar *default_to;
 	gboolean enable_default_reply_to;
 	gchar *default_reply_to;
+	gboolean enable_default_cc;
+	gchar *default_cc;
+	gboolean enable_default_bcc;
+	gchar *default_bcc;
+	gboolean enable_default_replyto;
+	gchar *default_replyto;
 	gboolean enable_simplify_subject;
 #ifndef G_OS_WIN32
 	gchar *simplify_subject_regexp;
@@ -78,6 +84,7 @@ struct _FolderItemPrefs {
 void folder_item_prefs_read_config(FolderItem * item);
 void folder_item_prefs_save_config(FolderItem * item);
 void folder_item_prefs_save_config_recursive(FolderItem * item);
+void folder_prefs_save_config_recursive(Folder *folder);
 FolderItemPrefs *folder_item_prefs_new(void);
 void folder_item_prefs_free(FolderItemPrefs * prefs);
 void folder_item_prefs_copy_prefs(FolderItem * src, FolderItem * dest);
